@@ -33,10 +33,16 @@
 #  define VTKFILTERSIMAGING_DEPRECATED_NO_EXPORT VTKFILTERSIMAGING_NO_EXPORT VTKFILTERSIMAGING_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKFILTERSIMAGING_NO_DEPRECATED
 #    define VTKFILTERSIMAGING_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkFiltersImagingModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKFILTERSIMAGING_EXPORT_H */
