@@ -33,10 +33,16 @@
 #  define VTKFILTERSSMP_DEPRECATED_NO_EXPORT VTKFILTERSSMP_NO_EXPORT VTKFILTERSSMP_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKFILTERSSMP_NO_DEPRECATED
 #    define VTKFILTERSSMP_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkFiltersSMPModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKFILTERSSMP_EXPORT_H */
