@@ -33,10 +33,16 @@
 #  define VTKIMAGINGFOURIER_DEPRECATED_NO_EXPORT VTKIMAGINGFOURIER_NO_EXPORT VTKIMAGINGFOURIER_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKIMAGINGFOURIER_NO_DEPRECATED
 #    define VTKIMAGINGFOURIER_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkImagingFourierModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKIMAGINGFOURIER_EXPORT_H */
