@@ -33,10 +33,16 @@
 #  define VTKRENDERINGVOLUMEAMR_DEPRECATED_NO_EXPORT VTKRENDERINGVOLUMEAMR_NO_EXPORT VTKRENDERINGVOLUMEAMR_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKRENDERINGVOLUMEAMR_NO_DEPRECATED
 #    define VTKRENDERINGVOLUMEAMR_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkRenderingVolumeAMRModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKRENDERINGVOLUMEAMR_EXPORT_H */
